export interface RootConfig {
  'brtc.audio.config'?: BrtcAudioConfig;
  'brtc.video.params'?: BrtcVideoParams;
  'brtc.field.trials'?: BrtcFieldTrials;
  'brtc.global.config'?: BrtcGlobalConfig;
  'brtc.app.config'?: BrtcAppConfig;
}

interface BrtcAudioConfig {
  aec?: boolean;
  ns?: boolean;
  agc?: boolean;
  agc2?: boolean;
  agc2_gain_db?: number;
  daaec?: boolean;
  builtInaec?: boolean;
  builtInns?: boolean;
  builtInagc?: boolean;
  highpass_filter?: boolean;
  voice_detection_enable?: boolean;
  agc2_adaptive_digital_init_gain_db?: number;
  aec_dump_enable?: boolean;
  aec_dump_file_path?: string;
  android_builtinaec_whitelist?: string[];
  android_daaec_blacklist?: string[];
  android_audio_source_whitelist?: string[];
  sdk_default_microphone_volume?: number;
  sdk_default_speaker_volume?: number;
  precreate_audiorecord?: boolean;
  audio_omlsa_file_path?: string;
}

interface BrtcVideoParams {
  local_mirror?: number;
  enc_mirror?: number;
  codec_name?: number;
  android_hardware_encode_blacklist?: string[];
  camera_enum_type?: {
    type: string;
    to_texture: boolean;
  };
  video_hw_decoder_limit?: {
    width: number;
    height: number;
  };
}

interface BrtcFieldTrials {
  [key: string]: string;
}

interface BrtcGlobalConfig {
  native_log?: {
    enable: boolean;
    level: number;
  };
  enable_webrtc?: boolean;
  hw_dec_limit?: {
    Codec: string;
    MaxCount: number;
  }[];
  sdk_domain?: string;
  api_url?: string;
  api_url_backup?: string;
  room_type?: 0 | 1;
  silence?: 0 | 1;
  proxies?: {
    dcurl: string;
    delay: number;
    location: string;
    url: string;
  }[];
  trust_all_ssl?: boolean;
  vt_timeout?: number;
  vt_max_retry?: number;
  debug_debugging_information?: boolean;
}

interface BrtcAppConfig {
  comments?: string;
}

// 使用样例：
// const rootConfig: RootConfig = {
//   'brtc.audio.config': {
//     aec: false,
//     agc2_gain_db: 15,
//     android_audio_source_whitelist: ['SM-G9810', 'SM-G9500', 'Pixel 6 Pro']
//   },
//   'brtc.video.params': {
//     enc_mirror: 0,
//     video_hw_decoder_limit: {
//       width: 640,
//       height: 480
//     }
//   },
//   'brtc.field.trials': {
//     'Brtc-BweTcc/': 'Disabled/',
//     'Brtc-CustomizeVideoAdaption/': 'Disabled/',
//     'Brtc-FECRedundancy/': 'Disabled/',
//     'Brtc-FECVersion/': '1.0/'
//   }
// };
//
// rootConfig['brtc.audio.config']!.aec = true;
// rootConfig['brtc.video.params']!.enc_mirror = 1;