export class BrtcRoomParams {
  appId: string;
  roomId: string;
  userId: string;
  userSig: string;
}

export enum BrtcVideoStreamType {
  BIG = 0,
  SMALL = 1,
  SUB = 2
}

export enum BrtcAudioQuality {
  SPEECH = 1,
  DEFAULT = 2,
  MUSIC = 3
}

export enum BrtcVideoResolutionMode {
  LANDSCAPE = 0,
  PORTRAIT = 1
}

export class BrtcVideoEncParam {
  bandWidth: number = 400;
  width: number = 640;
  height: number = 360;
  fps: number = 15;
  resolutionMode: BrtcVideoResolutionMode = BrtcVideoResolutionMode.LANDSCAPE;
}

export enum BrtcVideoQosPreference {
  SMOOTH = 1,
  CLEAR = 2
}

export enum BrtcVideoRotation {
  ROTATION_0 = 0,
  ROTATION_90 = 1,
  ROTATION_180 = 2,
  ROTATION_270 = 3
}

export enum BrtcVideoFillMode {
  FILL = 0,
  FIT = 1
}

export enum BrtcVideoMirrorType {
  NO_MIRROR = 0,
  HORIZONTAL = 1
}

export enum BrtcLogLevel {
  ERROR = 0,
  WARNING = 1,
  INFO = 2,
  DEBUG= 3
}

export class BrtcRenderParams {
  fillMode: BrtcVideoFillMode;
  rotation: BrtcVideoRotation;
  mirrorType: BrtcVideoMirrorType;

  constructor(fillMode: BrtcVideoFillMode, rotation: BrtcVideoRotation, mirrorType: BrtcVideoMirrorType) {
    this.fillMode = fillMode;
    this.rotation = rotation;
    this.mirrorType = mirrorType;
  }
}

export class BrtcNetworkQosParam {
  preference: BrtcVideoQosPreference;
  streamType: BrtcVideoStreamType

  constructor(pref: BrtcVideoQosPreference, type: BrtcVideoStreamType) {
    this.preference = pref;
    this.streamType = type;
  }
}

export class BrtcEngineAdvancedConfig {
  constructor() {
    this.config = new Map();
    this.applicationContext = null;
  }
  config: Map<string, string>;
  applicationContext: Object;
}
