import { BrtcEngineImpl } from './BrtcEngineImpl';
import * as brtc from "./BrtcDefines";
import { BrtcListener } from './BrtcEventHandler';
import { BrtcDeviceManager } from './BrtcDeviceManager';

type CallBack = (...args: any[]) => void;

export default class BrtcEngine {

  static getInstance(): BrtcEngineImpl | null {
    return BrtcEngineImpl.getInstance();
  }

  static createEngine(config: brtc.BrtcEngineAdvancedConfig | null): Promise<BrtcEngineImpl | null> {
    return BrtcEngineImpl.createEngine(config);
  }

  static destroyEngine(): void {
    BrtcEngineImpl.destroyEngine();
  }

  static getSdkVersion(): string {
    return BrtcEngineImpl.getSdkVersion();
  }

  static setConsoleEnabled(enabled: boolean): void {
    BrtcEngineImpl.setConsoleEnabled(enabled);
  }

  static setLogLevel(level: brtc.BrtcLogLevel): void {
    BrtcEngineImpl.setLogLevel(level);
  }

  static setLogPath(path: string): void {
    BrtcEngineImpl.setLogPath(path);
  }

  callExperimentalApi(jsonStr: string): void {
    BrtcEngineImpl.getInstance().callExperimentalApi(jsonStr);
  }

  setDefaultStreamRecvMode(autoRecvAudio: boolean, autoRecvVideo: boolean): void {
    BrtcEngineImpl.getInstance().setDefaultStreamRecvMode(autoRecvAudio, autoRecvVideo);
  }

  setNetworkQosParam(qosParam: brtc.BrtcNetworkQosParam): void {
    BrtcEngineImpl.getInstance().setNetworkQosParam(qosParam);
  }

  enableSmallVideoStream(enable: boolean, encParam: brtc.BrtcVideoEncParam): void {
    BrtcEngineImpl.getInstance().enableSmallVideoStream(enable, encParam);
  }

  setVideoEncoderParam(encParam: brtc.BrtcVideoEncParam): void {
    BrtcEngineImpl.getInstance().setVideoEncoderParam(encParam);
  }

  setVideoEncoderMirror(mirror: boolean): void {
    BrtcEngineImpl.getInstance().setVideoEncoderMirror(mirror);
  }

  setVideoEncoderRotation(rotation: brtc.BrtcVideoRotation): void {
    BrtcEngineImpl.getInstance().setVideoEncoderRotation(rotation);
  }

  enterRoom(roomParams: brtc.BrtcRoomParams): void {
    BrtcEngineImpl.getInstance().enterRoom(roomParams);
  }

  exitRoom(): void {
    BrtcEngineImpl.getInstance().exitRoom();
  }

  startLocalPreview(useFront: boolean): void {
    BrtcEngineImpl.getInstance().startLocalPreview(useFront);
  }

  stopLocalPreview(): void {
    BrtcEngineImpl.getInstance().stopLocalPreview();
  }

  startLocalAudio(quality: brtc.BrtcAudioQuality): void {
    BrtcEngineImpl.getInstance().startLocalAudio(quality);
  }

  stopLocalAudio(): void {
    BrtcEngineImpl.getInstance().stopLocalAudio()
  }

  muteLocalAudio(mute: boolean): void {
    BrtcEngineImpl.getInstance().muteLocalAudio(mute);
  }

  muteLocalVideo(streamType: brtc.BrtcVideoStreamType, mute: boolean): void {
    BrtcEngineImpl.getInstance().muteLocalVideo(streamType, mute);
  }

  muteRemoteAudio(userId: string, mute: boolean): void {
    BrtcEngineImpl.getInstance().muteRemoteAudio(userId, mute);
  }

  muteRemoteVideo(userId: string, streamType: brtc.BrtcVideoStreamType, mute: boolean): void {
    BrtcEngineImpl.getInstance().muteRemoteVideo(userId, streamType, mute);
  }

  muteAllRemoteAudio(mute: boolean): void {
    BrtcEngineImpl.getInstance().muteAllRemoteAudio(mute);
  }

  startScreenCapture(xComponentSurfaceId:string, streamType: brtc.BrtcVideoStreamType,
    encParam: brtc.BrtcVideoEncParam): void {
    BrtcEngineImpl.getInstance().startScreenCapture(xComponentSurfaceId, streamType, encParam);
  }

  stopScreenCapture(): void {
    BrtcEngineImpl.getInstance().stopScreenCapture();
  }

  getDeviceManager(): BrtcDeviceManager {
    return BrtcEngineImpl.getInstance().getDeviceManager();
  }

  startRemoteView(userId: string, streamType: brtc.BrtcVideoStreamType) {
    BrtcEngineImpl.getInstance().startRemoteView(userId, streamType);
  }

  stopRemoteView(userId: string, streamType: brtc.BrtcVideoStreamType) {
    BrtcEngineImpl.getInstance().stopRemoteView(userId, streamType);
  }

  setRemoteVideoStreamType(userId: string, streamType: brtc.BrtcVideoStreamType) {
    BrtcEngineImpl.getInstance().setRemoteVideoStreamType(userId, streamType);
  }

  setRenderParams(userId: string, streamType: brtc.BrtcVideoStreamType, params: brtc.BrtcRenderParams) {
    BrtcEngineImpl.getInstance().setRenderParams(userId, streamType, params);
  }

  on<EventType extends keyof BrtcListener>(event: EventType, callback: BrtcListener[EventType]) {
    BrtcEngineImpl.getInstance().on(event, callback);
  }

  off<EventType extends keyof BrtcListener>(event: EventType, callback: BrtcListener[EventType]) {
    BrtcEngineImpl.getInstance().off(event, callback);
  }

} //class BrtcEngine